@@ -132,7 +132,7 @@ int tc_filter(aframe_list_t *ptr, char *options)
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
   
-  if(ptr->tag & TC_PRE_S_PROCESS && ptr->tag & TC_AUDIO) {
+  if(ptr->tag & TC_PRE_S_PROCESS && ptr->tag & TC_AUDIO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
     
     total += (uint64_t) ptr->audio_size;
     
