@@ -234,7 +234,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
   
-  if(ptr->tag & TC_PRE_M_PROCESS && ptr->tag & TC_VIDEO) {
+  if(ptr->tag & TC_PRE_M_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
   //    memcpy(buffer, ptr->video_buf, SIZE_RGB_FRAME);
   //    memcpy(ptr->video_buf, buffer, SIZE_RGB_FRAME);
 
