@@ -215,7 +215,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
   
-  if(ptr->tag & TC_PRE_PROCESS && ptr->tag & TC_VIDEO) {
+  if(ptr->tag & TC_PRE_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
     
     if(vob->im_v_codec==CODEC_RGB) {
       generate_rgb_frame(ptr->video_buf, ptr->v_width, ptr->v_height);
