@@ -30,6 +30,7 @@ void decode_ac3(info_t *ipipe);
 void decode_a52(info_t *ipipe);
 void extract_ac3(info_t *ipipe);
 
+void decode_mp2(info_t *ipipe);
 void decode_mp3(info_t *ipipe);
 void extract_mp3(info_t *ipipe);
 
@@ -55,6 +56,7 @@ void decode_af6(info_t *ipipe);
 
 void decode_divx(info_t *ipipe);
 void decode_xvid(info_t *ipipe);
+void decode_mov(info_t *ipipe);
 
 void probe_yuv(info_t *ipipe);
 void probe_nuv(info_t *ipipe);
