@@ -98,7 +98,7 @@ int process_aud_frame(vob_t *vob, aframe_list_t *ptr)
   }
   
   if (skip) {
-      ptr->attributes |= TC_FRAME_IS_SKIPPED;
+      ptr->attributes |= TC_FRAME_IS_OUT_OF_RANGE;
       return 0;
   }
 
