@@ -66,7 +66,7 @@ int filter_next_free_id(void)
 
   for (n=0; n<MAX_FILTER; ++n) {
     // no filter
-    if (filter[n].name[0] == '\0')
+    if (!filter[n].name)
       break;
   }
   if (n >= MAX_FILTER) {
@@ -88,10 +88,10 @@ void plugin_fix_id(void)
     offset = filter[n].name;
 
     // no filter or already counted
-    if (filter[n].name[0] == '\0' || filter[n].id != 0) continue;
+    if (!filter[n].name || filter[n].id != 0) continue;
 
     for (i=n+1; i<MAX_FILTER; ++i) {
-      if (strcmp(filter[i].name,offset) == 0) {
+      if (filter[i].name && strcmp(filter[i].name,offset) == 0) {
 	count++;
 	filter[i].id = count;
       }
@@ -100,7 +100,7 @@ void plugin_fix_id(void)
   }
   if (verbose & TC_DEBUG) {
     for (n=0; n<MAX_FILTER; ++n) {
-      fprintf(stderr, "Filter[%d].name (%s) instance # (%d)\n", n, filter[n].name, filter[n].id);
+      fprintf(stderr, "Filter[%d].name (%s) instance # (%d)\n", n, (filter[n].name?filter[n].name:"-"), filter[n].id);
     }
   }
 }
@@ -135,14 +135,16 @@ int load_plugin(char *path) {
   int n;
   char *c;
   int id = filter_next_free_id();
+  int len;
 
 
   //replace "=" by "/0" in filter name
-  if(strlen(filter[id].name)==0) return(-1);
+  if(!filter[id].name || strlen(filter[id].name)==0) return(-1);
 
   filter[id].options=NULL;
 
-  for(n=0; n<strlen(filter[id].name); ++n) {
+  len = strlen(filter[id].name);
+  for(n=0; n<len; ++n) {
     if(filter[id].name[n]=='=') {
       filter[id].name[n]='\0';
       filter[id].options=filter[id].name+n+1;
@@ -200,8 +202,12 @@ int filter_single_init(int id)
   if(!plugins_loaded) return(1);    
 
   ptr.tag = TC_FILTER_INIT;
-
   ptr.filter_id = filter[id].id;
+ 
+  // This size is very wrong for audio filters, but it is the maximum size of
+  // the buffer a filter may get during that transcode run.
+  ptr.size = tc_frame_height_max*tc_frame_width_max*3;
+
   if(filter[id].entry(&ptr, filter[id].options)<0) {
     tc_warn("filter plugin '%s' returned error - plugin skipped", filter[id].name);
     filter[id].status=0;
@@ -292,7 +298,7 @@ int plugin_find_id(char *s)
   for (n=0; n<MAX_FILTER; ++n) {
 	  
     if ( ( ((instance==-1)?filter[n].id:instance) == filter[n].id) && 
-		  (strncmp(filter[n].name, s, len) == 0)) {
+		  (filter[n].name && strncmp(filter[n].name, s, len) == 0)) {
       return n;
     }
   }
@@ -308,7 +314,7 @@ int filter_single_configure_handle (int handle, char *options)
     // disable it.
     plugin_disable_id (handle);
     
-    // filter_ need to be restartet to take new options into account
+    // filter_ need to be restarted to take new options into account
     fprintf (stderr, "[%s] filter_close (%d:%s)\n", __FILE__, ret, options);
     filter_single_close(handle);
 
@@ -330,7 +336,7 @@ filter_t * plugin_by_name(char *name, int instance)
 
   for (n=0; n<MAX_FILTER; ++n) {
     if ( ( ((instance==-1)?filter[n].id:instance) == filter[n].id) && 
-	            (strcmp(filter[n].name, name) == 0)) {
+	            (filter[n].name && strcmp(filter[n].name, name) == 0)) {
       t = &filter[n];
     }
   }
@@ -344,7 +350,10 @@ int load_single_plugin (char *mfilter_string)
 
   fprintf(stderr, "[%s] Loading (%s) ..\n", __FILE__, mfilter_string);
 
+  filter[id].namelen = strlen(mfilter_string);
+  filter[id].name    = (char *) malloc (filter[id].namelen+1);
   strcpy(filter[id].name, mfilter_string);
+
   if (load_plugin(vob->mod_path)==0)  {
     plugins++;
     plugins_loaded = 1;
@@ -358,15 +367,21 @@ int load_single_plugin (char *mfilter_string)
   return 0;
 }
 
-char *get_next_filter_name(char *name, char *string)
+char *get_next_filter_name(char **name, int *namelen, char *string)
 {
   char *res = string;
+  int len = 0;
 
   if(string[0]=='\0') return(NULL);
 
   while (1) {
       if((res=strchr(res, ','))==NULL) {
-	  strcpy(name, string);
+	  *namelen = strlen(string);
+	  len = *namelen;
+	  *name = (char *)malloc(len+2);
+	  memset(*name, 0, len+2);
+	  memcpy(*name, string, len);
+
 	  //return pointer to '\0'
 	  return(string+strlen(string));
       }
@@ -379,9 +394,12 @@ char *get_next_filter_name(char *name, char *string)
 
       break;
   }
+  *namelen = (int)(res-string);
+  len = *namelen;
+  *name = (char *)malloc(len+2);
 
-  
-  memcpy(name, string, (int)(res-string));
+  memset(*name, 0, len+2);
+  memcpy(*name, string, len);
   
   return(res+1);
 }
@@ -402,7 +420,7 @@ int plugin_list_disabled(char *buf)
     int n, pos=0;
 
     for (n=0; n<MAX_FILTER; n++) {
-	if ( (filter[n].status == 0) && strlen(filter[n].name)) {
+	if ( (filter[n].status == 0) && filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
 		pos = sprintf(buf, "\"%s\"", filter[n].name);
 	    } else {
@@ -419,7 +437,7 @@ int plugin_list_enabled(char *buf)
     int n, pos=0;
 
     for (n=0; n<MAX_FILTER; n++) {
-	if ( (filter[n].status == 1) && strlen(filter[n].name)) {
+	if ( (filter[n].status == 1) && filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
 		pos = sprintf(buf, "\"%s\"", filter[n].name);
 	    } else {
@@ -436,7 +454,7 @@ int plugin_list_loaded(char *buf)
     int n, pos=0;
 
     for (n=0; n<MAX_FILTER; n++) {
-	if (strlen(filter[n].name)) {
+	if (filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
 		pos = sprintf(buf, "\"%s\"", filter[n].name);
 	    } else {
@@ -477,10 +495,19 @@ int init_plugin(vob_t *vob)
     if(plugins_string!= NULL) fprintf(stderr, "(%s) %s\n", __FILE__, plugins_string);
   
   // need to load the plugins
+
+  //memset(filter, 0, sizeof(filter_t)*MAX_FILTER);
+
+  for(n=0; n<MAX_FILTER; ++n) {
+      //memset(&(filter[n]), 0, sizeof(filter[n]));
+      filter[n].options = NULL;
+      filter[n].name = NULL;
+  }
   
+  j=0;
   for(n=0; n<MAX_FILTER; ++n) {
     
-    if((offset=get_next_filter_name(filter[j].name, offset))==NULL) break;
+    if((offset=get_next_filter_name(&(filter[j].name), &(filter[j].namelen), offset))==NULL) break;
     
     if(load_plugin(vob->mod_path)==0) ++j;
   }
@@ -495,7 +522,10 @@ int process_aud_plugins(aframe_list_t *ptr)
     
     int n;
 
-    if (ptr->attributes & TC_FRAME_IS_SKIPPED)
+    // The filters now do skip for themselfs
+    //if (ptr->attributes & TC_FRAME_IS_SKIPPED) return 0;
+
+    if (ptr->attributes & TC_FRAME_IS_OUT_OF_RANGE)
 	return 0;
 
     for(n=0; n<plugins; ++n) {
@@ -514,7 +544,10 @@ int process_vid_plugins(vframe_list_t *ptr)
     
     int n;
 
-    if (ptr->attributes & TC_FRAME_IS_SKIPPED)
+    // The filters now do skip for themselfs
+    //if (ptr->attributes & TC_FRAME_IS_SKIPPED) return 0;
+
+    if (ptr->attributes & TC_FRAME_IS_OUT_OF_RANGE)
 	return 0;
 
     for(n=0; n<plugins; ++n) {
@@ -587,6 +620,7 @@ int plugin_single_close(int id)
 
     if(filter[id].unload)  {
 	dlclose(filter[id].handle);
+	free(filter[id].name);
 	memset (&filter[id], 0, sizeof (filter_t));
     }
 
