@@ -52,8 +52,6 @@ unsigned long *aa_table_y;
 unsigned long *aa_table_d;
 
 
-// tmp rowbuffer
-char rowbuffer[TC_MAX_V_FRAME_WIDTH * BPP/3];
 char *tmp_image=NULL;
 
 
@@ -1100,6 +1098,9 @@ int process_vid_frame(vob_t *vob, vframe_list_t *ptr)
 
   if (ptr->attributes & TC_FRAME_IS_SKIPPED)
       return 0;
+
+  if (ptr->attributes & TC_FRAME_IS_OUT_OF_RANGE)
+      return 0;
   
   // check if a frame data are in RGB colorspace
   
