@@ -112,6 +112,9 @@ void yuv_flip_core(char *image, int width, int height)
 {
 
   char *in, *out;
+
+  // this shouldn't be too hard on the stack
+  char rowbuffer[TC_MAX_V_FRAME_WIDTH];
   
   unsigned int y, block;  
   
@@ -1534,6 +1537,9 @@ void yuv_deinterlace_linear_blend(char *image, char *tmp, int width, int height)
   
   //process only Y component
   yuv_deinterlace_linear_blend_core(image, tmp, width, height);
+  // cr/cb
+  yuv_deinterlace_linear_blend_core(image+width*height, tmp, width/2, height/2);
+  yuv_deinterlace_linear_blend_core(image+width*height*5/4, tmp, width/2, height/2);
 
   clear_mmx();
 }
